@@ -19,14 +19,15 @@ except ImportError:
 
 class BlueDo(Gtk.Application):
     project_name = 'bluedo'
-    project_version = .52
+    project_version = .56
     config_path = appdirs.user_config_dir(project_name) + '/' + project_name + '.ini'
     config_section = 'CONFIG'
-    run_path = os.path.dirname(os.path.realpath(__file__))
+    run_path = os.path.dirname(os.path.realpath(__file__)) + '/'
+    autostart_dir = os.getenv("HOME") + '/.config/autostart/'
 
     builder = None
     enabled = False
-    debug = True
+    debug = False
     threshold = 0
     interval = 4
     away_count = 5
@@ -101,6 +102,8 @@ class BlueDo(Gtk.Application):
 
         self.link_bluetoothsettings = self.builder.get_object("link_bluetoothsettings")
         self.link_bluetoothsettings.set_label("Bluetooth settings")
+        self.menuitem_autostart = self.builder.get_object("menuitem_autostart")
+        self.menuitem_autostart.set_active(self.check_autostart())
 
         self.show_animation()
 
@@ -166,11 +169,11 @@ class BlueDo(Gtk.Application):
         self.advanced_clicked(self.menuitem_advanced)
 
         # Tray icon
-        indicator = AppIndicator3.Indicator.new("customtray",
-            self.run_path + "/bluedo_indicator.png",
+        self.indicator = AppIndicator3.Indicator.new("customtray",
+            self.run_path + "bluedo.png",
             AppIndicator3.IndicatorCategory.APPLICATION_STATUS)
-        indicator.set_status(AppIndicator3.IndicatorStatus.ACTIVE)
-        indicator.set_menu(self.dropdown_menu)
+        self.indicator.set_status(AppIndicator3.IndicatorStatus.ACTIVE)
+        self.indicator.set_menu(self.dropdown_menu)
 
         if self.minimized:
             self.menuitem_minimize.set_active(True)
@@ -339,6 +342,11 @@ class BlueDo(Gtk.Application):
         ''' Toggle enable '''
         self.button_enabled.set_active(not self.button_enabled.get_active())
 
+    def autostart_clicked(self, state):
+        ''' Toggle autostart '''
+        
+        self.create_autostart(ensure=self.menuitem_autostart.get_active())
+
     def bluetoothsettings_clicked(self, state):
         ''' Open gnome-control-center on bluetooth '''
 
@@ -426,6 +434,26 @@ class BlueDo(Gtk.Application):
         if "true" in self.config.get(self.config_section, 'enabled', fallback='false').lower():
             self.enabled = True
 
+    def create_autostart(self, ensure=True):
+        """ Create autostart file. Or deletes if not ensure. """
+
+        if ensure:
+            with open(self.autostart_dir + self.project_name + '.desktop', 'w') as f:
+                f.write("""[Desktop Entry]
+Name=BlueDo
+Comment=Bluetooth proximity automation
+Exec=bluedo
+Icon=bluedo
+Terminal=false
+Type=Application
+Categories=Utility;
+""")
+        else:
+            os.remove(self.autostart_dir + self.project_name + '.desktop')
+
+    def check_autostart(self):
+        return os.path.isfile(self.autostart_dir + self.project_name + '.desktop')
+
 #
 # Bluetooth
 #
@@ -451,11 +479,18 @@ class BlueDo(Gtk.Application):
             )
 
             for line in iter(proc.stdout.readline, b''):
+                if BlueDo.debug:
+                    print("bluetoothctl line: " + line)
                 if line.strip() == '': # iter calls until output is ''
                     break
                 if line == 'No default controller available\n':
                     break
-                addr = line.split()[1]
+                addr = ''
+                try:
+                    addr = line.split()[1]
+                except IndexError:
+                    print("Info: Skipping empty line from bluetoothctl.")
+                    continue
                 name = ' '.join(line.split()[2:])
                 devices += [(name, addr)]
 
@@ -576,6 +611,8 @@ class BlueDo(Gtk.Application):
         if self.debug:
             syslog.syslog("Here")
 
+        self.indicator.set_icon_full(self.run_path + "phonelink-white-18dp.svg", "Here")
+
         if self.check_hereunlock.get_active():
             unlock()
 
@@ -592,6 +629,8 @@ class BlueDo(Gtk.Application):
         if self.debug:
             syslog.syslog("Away")
 
+        self.indicator.set_icon_full(self.run_path + "phonelink_off-white-18dp.svg", "Away")
+
         if self.check_awaylock.get_active():
             lock()
 
@@ -605,7 +644,6 @@ class BlueDo(Gtk.Application):
             run_user_command(cmd=self.entry_away.get_text())
 
 
-
 #
 # Static functions
 #
